@@ -1,3 +1,4 @@
+# https://github.com/ncss-tech/aqp/issues/75
 # class def for main class within aqp
 .SoilProfileCollectionValidity <- function(object) {
 	
@@ -43,6 +44,7 @@ setClass(
   Class='SoilProfileCollection', 
   representation=representation(
     idcol='character', # column name containing IDs
+    hzidcol='character',
     depthcols='character', # 2 element vector with column names for hz top, bottom
     metadata='data.frame', # single-row dataframe with key-value mapping
     horizons='data.frame', # all horizons sorted by ID, top
@@ -52,6 +54,7 @@ setClass(
   ),
   prototype=prototype(
     idcol='id',
+    hzidcol='hzID',
     depthcols=c('top','bottom'),
     metadata=data.frame(stringsAsFactors=FALSE), # default units are unkown
     horizons=data.frame(stringsAsFactors=FALSE),
