@@ -67,6 +67,28 @@ setMethod("idname", "SoilProfileCollection",
     return(object@idcol)
 )
 
+## horizon ID name
+if (!isGeneric("hzidname"))
+  setGeneric("hzidname", function(object, ...) standardGeneric("hzidname"))
+
+setMethod("hzidname", "SoilProfileCollection",
+          function(object)
+            return(object@hzidcol)
+)
+
+## get horizon IDs
+if (!isGeneric("hzID"))
+  setGeneric("hzID", function(object, ...) standardGeneric("hzID"))
+
+setMethod("hzID", "SoilProfileCollection",
+          function(object) {
+            h <- horizons(object)
+            res <- h[[hzidname(object)]]
+            return(res)
+          }
+            
+)
+
 
 ## distinct profile IDs
 if (!isGeneric("profile_id"))
@@ -189,94 +211,6 @@ setMethod("horizonNames", "SoilProfileCollection",
 ## overloads
 ##
 
-### This will be greatly improved with new class structure
-## concatentation
-## TODO: concatenation of data with duplicated IDs in @site, but unique data in other @site fields, will result in corrupt SPC
-## TODO: duplicates in @sp will cause errors
-## TODO: duplicates are removed in all other slots... does this make sense?
-rbind.SoilProfileCollection <- function(...) {
-	# setup some defaults
-	options(stringsAsFactors=FALSE)
-	
-	# parse dots
-	objects <- list(...)
-	names(objects) <- NULL
-	
-	# short-circuits
-	if(length(objects) == 0)
-		return(NULL)
-	if(length(objects) == 1)
-		return(objects[1])
-	
-	# combine pieces
-	# should have length of 1
-	o.idname <- unique(lapply(objects, idname))
-	o.depth.units <- unique(lapply(objects, depth_units))
-	o.hz.depths <- unique(lapply(objects, horizonDepths))
-	o.m <- unique(lapply(objects, aqp::metadata))
-	o.coords <- unique(lapply(objects, function(i) ncol(coordinates(i))))
-	o.p4s <- unique(lapply(objects, proj4string))
-	
-	# should have length > 1
-	o.h <- lapply(objects, horizons)
-	o.s <- lapply(objects, site)
-	o.d <- lapply(objects, diagnostic_hz)
-	o.sp <- lapply(objects, slot, 'sp')
-	
-	# sanity checks:
-	if(length(o.idname) > 1)
-		stop('inconsistent ID names', call.=FALSE)
-	if(length(o.depth.units) > 1)
-		stop('inconsistent depth units', call.=FALSE)
-	if(length(o.hz.depths) > 1)
-		stop('inconsistent depth columns', call.=FALSE)
-	if(length(o.m) > 1)
-		stop('inconsistent metadata', call.=FALSE)
-	
-	# spatial data may be missing...
-	if(length(o.coords) > 1)
-		stop('inconsistent spatial data', call.=FALSE)
-	if(length(o.p4s) > 1)
-		stop('inconsistent CRS', call.=FALSE)
-	
-	# generate new SPC components
-	o.h <- unique(do.call('rbind', o.h)) # horizon data
-	o.s <- unique(do.call('rbind', o.s)) # site data
-	o.d <- unique(do.call('rbind', o.d)) # diagnostic data, leave as-is
-	
-	## 2015-12-18: removed re-ordering, was creating corrupt SPC objects
-	##             site and horizon data
-  
-	# spatial points require some more effort when spatial data are missing
-	o.1.sp <- objects[[1]]@sp
-	if(ncol(coordinates(o.1.sp)) == 1) # missing spatial data
-		o.sp <- o.1.sp # copy the first filler
-	
-	## 2015-12-18: added call to specific function: "sp::rbind.SpatialPoints"
-	# not missing spatial data
-	else
-		o.sp <- do.call("rbind.SpatialPoints", o.sp) # rbind properly
-	
-	# make SPC and return
-	res <- SoilProfileCollection(idcol=o.idname[[1]], depthcols=o.hz.depths[[1]], metadata=o.m[[1]], horizons=o.h, site=o.s, sp=o.sp, diagnostic=o.d)
-	
-# 	# one more final check:
-# 	print(profile_id(res))
-# 	print( site(res)[[idname(res)]])
-# 	print(site(res))
-	
-	if(length(profile_id(res)) != length(site(res)[[idname(res)]]))
-	  stop("SPC object corruption. This shouldn't happen and will be fixed in aqp 2.0", call. = FALSE)
-	if(! all.equal(profile_id(res), site(res)[[idname(res)]]))
-	  stop("SPC object corruption. This shouldn't happen and will be fixed in aqp 2.0", call. = FALSE)
-  
-	return(res)
-}
-
-
-## TODO: this doesn't work as expected ... fix in 2.0
-## overload rbind
-#setMethod("rbind", "SoilProfileCollection", .rbind.SoilProfileCollection)
 
 
 
@@ -351,6 +285,9 @@ setMethod(f='length', signature='SoilProfileCollection',
 )
 
 # overload nrow() to give us the number of horizons in the collection
+if (!isGeneric('nrow'))
+  setGeneric('nrow', function(x) standardGeneric('nrow'))
+
 setMethod(f='nrow', signature='SoilProfileCollection',
   definition=function(x){
   nrow(x@horizons)
